
import java.util.Collection;
import java.util.List;

/**
 * A word index allows for a quick search over a large collection of words. It
 * supports two services, the first is populating the index with words, the
 * second is searching for a word.
 */
public interface WordIndex {

	/**
	 * Add the words originating in the specifies URL.
	 * 
	 * @param words
	 *            - collection of words to add to the index
	 * @param strURL
	 *            - the location of the page containing the words
	 */
	void index(Collection<String> words, String strURL);

	/**
	 * Search for pages containing a given word in the index
	 * 
	 * @param word
	 *            - the word to search
	 * @return A list of pages containing the word. The pages are ordered
	 *         according to the relative importance of the word within them.
	 */
	List<String> search(String word);

	
	/**
	 * Search for pages that are similar to a given URL in the index
	 * 
	 * @param strURL
	 *            - a URL for which similar web pages are to be found 
	 * @return A list of pages that are similar to the given URL based on contained words.
	 * 		   The pages are ordered based on similarity to the given URL.
	 */
	List<String> findSimilarPages(String strURL);
}